@@ -1,10 +1,10 @@
 /***********************************************************************
  * vanessa_logger.h                                       September 2000
- * Horms                                              horms@verge.net.au
+ * Simon Horman                                       horms@verge.net.au
  *
  * vanessa_logger
  * Generic logging layer
- * Copyright (C) 2000-2004  Horms
+ * Copyright (C) 2000-2008  Simon Horman <horms@verge.net.au>
  * 
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -40,7 +40,7 @@ typedef void (*vanessa_logger_log_function_va_t)
 /*
  * NB: There was a fundamental design error in the original
  * implementation of logging to functions such that it cannot work
- * wit vanessa_loggers internal framework. Thus
+ * with vanessa_logger's internal framework. Thus
  * vanessa_logger_log_function_t has been replaced by
  * vanessa_logger_log_function_va_t. Please do not use
  * vanessa_logger_log_function_t.
@@ -52,7 +52,7 @@ typedef void (*vanessa_logger_log_function_va_t)
  * when I wrote this code. Perhaps I was just tired. But in any case
  * it was wrong.
  *
- * Horms, December 2002
+ * Simon Horman, December 2002
  *
  * typedef int (*vanessa_logger_log_function_t) 
  *		(int priority, const char *fmt, ...);
@@ -363,7 +363,7 @@ vanessa_logger_get_flag(vanessa_logger_t * vl);
 #define VANESSA_LOGGER_STR_DUMP_HEX 0x1
 
 char *
-vanessa_logger_str_dump(vanessa_logger_t * vl, const unsigned char *buffer, 
+vanessa_logger_str_dump(vanessa_logger_t * vl, const char *buffer, 
 		const size_t buffer_length, vanessa_logger_flag_t flag);
 
 
@@ -377,7 +377,6 @@ vanessa_logger_str_dump(vanessa_logger_t * vl, const unsigned char *buffer,
 
 
 extern vanessa_logger_t *__vanessa_logger_vl;
-extern int errno;
 
 /**********************************************************************
  * vanessa_logger_vl_set
@@ -386,13 +385,29 @@ extern int errno;
  * set to NULL (default). That is you _must_ call this function to 
  * enable logging using convenience macros.
  * pre: logger: pointer to a vanessa_logger
- * post: logger for ip_vs_nl is set to logger
+ * post: logger for convenience marcros is set to logger
  * return: none
  **********************************************************************/
 
 #define vanessa_logger_set(_vl) __vanessa_logger_vl=(_vl)
 
 
+/**********************************************************************
+ * vanessa_logger_vl_set_filehandle
+ * set the logger function to a logger created for the filehandle 
+ * No logging will take place using conveineince macros if logger is set to
+ * NULL (default). That is you _must_ call one of the vanessa_logger_vl_set
+ * functions to enable logging using convenience macros.
+ * pre:  fd: filehandle to log to 
+ * post: logger for filehandle is created and set as the 
+ *       logger for convenience marcros 
+ * created for the filehandle return: none
+ **********************************************************************/
+
+vanessa_logger_t *
+vanessa_logger_set_filehandle(FILE *fh);
+
+
 /**********************************************************************
  * vanessa_logger_vl_unset
  * set logger to use with convenience macros to NULL
@@ -434,52 +449,52 @@ extern int errno;
  */
 
 #define VANESSA_LOGGER_LOG_UNSAFE(priority, fmt, ...) \
-	vanessa_logger_log(__vanessa_logger_vl, priority, fmt, __VA_ARGS__);
+	vanessa_logger_log(__vanessa_logger_vl, priority, fmt, __VA_ARGS__)
 
 #define VANESSA_LOGGER_LOG(priority, str) \
 	vanessa_logger_log(__vanessa_logger_vl, priority, "%s", str)
 
 #define VANESSA_LOGGER_DEBUG_UNSAFE(fmt, ...) \
 	_vanessa_logger_log_prefix(__vanessa_logger_vl, LOG_DEBUG, \
-		__FUNCTION__, fmt, __VA_ARGS__);
+		__FUNCTION__, fmt, __VA_ARGS__)
 
 #define VANESSA_LOGGER_DEBUG(str) \
 	_vanessa_logger_log_prefix(__vanessa_logger_vl, LOG_DEBUG, \
-		__FUNCTION__, "%s", str);
+		__FUNCTION__, "%s", str)
 
 #define VANESSA_LOGGER_DEBUG_ERRNO(str) \
 	_vanessa_logger_log_prefix(__vanessa_logger_vl, LOG_DEBUG, \
-		__FUNCTION__, "%s: %s", str, strerror(errno));
+		__FUNCTION__, "%s: %s", str, strerror(errno))
 
 #define VANESSA_LOGGER_DEBUG_HERRNO(str) \
 	_vanessa_logger_log_prefix(__vanessa_logger_vl, LOG_DEBUG, \
 		__FUNCTION__, "%s: %s", str, \
-		vanessa_logger_strherror(h_errno));
+		vanessa_logger_strherror(h_errno))
 
 #define VANESSA_LOGGER_DEBUG_RAW_UNSAFE(fmt, ...) \
 	vanessa_logger_log(__vanessa_logger_vl, LOG_DEBUG, \
-		fmt, __VA_ARGS__);
+		fmt, __VA_ARGS__)
 
 #define VANESSA_LOGGER_DEBUG_RAW(str) \
-	vanessa_logger_log(__vanessa_logger_vl, LOG_DEBUG, "%s", str);
+	vanessa_logger_log(__vanessa_logger_vl, LOG_DEBUG, "%s", str)
 
 #define VANESSA_LOGGER_INFO_UNSAFE(fmt, ...) \
-	vanessa_logger_log(__vanessa_logger_vl, LOG_INFO, fmt, __VA_ARGS__);
+	vanessa_logger_log(__vanessa_logger_vl, LOG_INFO, fmt, __VA_ARGS__)
 
 #define VANESSA_LOGGER_INFO(str) \
-	vanessa_logger_log(__vanessa_logger_vl, LOG_INFO, "%s", str);
+	vanessa_logger_log(__vanessa_logger_vl, LOG_INFO, "%s", str)
 
 #define VANESSA_LOGGER_ERR_UNSAFE(fmt, ...) \
-	vanessa_logger_log(__vanessa_logger_vl, LOG_ERR, fmt, __VA_ARGS__);
+	vanessa_logger_log(__vanessa_logger_vl, LOG_ERR, fmt, __VA_ARGS__)
 
 #define VANESSA_LOGGER_ERR_RAW_UNSAFE(fmt, ...) \
-	vanessa_logger_log(__vanessa_logger_vl, LOG_ERR, fmt, __VA_ARGS__);
+	vanessa_logger_log(__vanessa_logger_vl, LOG_ERR, fmt, __VA_ARGS__)
 
 #define VANESSA_LOGGER_ERR(str) \
-	vanessa_logger_log(__vanessa_logger_vl, LOG_ERR, "%s", str);
+	vanessa_logger_log(__vanessa_logger_vl, LOG_ERR, "%s", str)
 
 #define VANESSA_LOGGER_RAW_ERR(str) \
-	vanessa_logger_log(__vanessa_logger_vl, LOG_ERR, "%s", str);
+	vanessa_logger_log(__vanessa_logger_vl, LOG_ERR, "%s", str)
 
 #define VANESSA_LOGGER_DUMP(buffer, buffer_length, flag) \
 	vanessa_logger_str_dump(__vanessa_logger_vl, (buffer), \
